How To Contribute
=================

``django-pandas`` is always open for suggestions and contributions
by generous developers. I’ve collected a few tips to get you started.

Please:

- Obey `PEP 8`_ and `PEP 257`_.
- *Always* add tests and docs for your code.
- Add yourself to the AUTHORS.rst_ file in an alphabetical fashion.
- Write `good commit messages`_.
- Ideally, squash_ your commits, i.e. make your pull requests just one commit.

Thank you for considering to contribute to ``django-pandas``.


.. _`squash`: http://gitready.com/advanced/2009/02/10/squashing-commits-with-rebase.html
.. _`PEP 8`: http://www.python.org/dev/peps/pep-0008/
.. _`PEP 257`: http://www.python.org/dev/peps/pep-0257/
.. _`good commit messages`: http://tbaggery.com/2008/04/19/a-note-about-git-commit-messages.html
.. _`AUTHORS.rst`: https://github.com/chrisdev/django-pandas/blob/master/AUTHORS.rst
